@@ -21,7 +21,7 @@ class BlyncCommand(BitField):
             logger.error(f"Failed to update {obj!r} after setting {self.name}")
 
 
-class BlyncSpeed(BitField):
+class BlyncSpeed(BlyncCommand):
     # speed gets it's own descriptor implementation due to it's being a
     # flag instead of a "value" and this was easier than trying to
     # shoehorn the logic into the BlyncCommand descriptor.
@@ -33,18 +33,110 @@ class BlyncSpeed(BitField):
 
     def __get__(self, obj, type=None) -> object:
         v = super().__get__(obj, type)
-        return FlashSpeed.speed_for_value(v)
+        return FlashSpeed.value_for_speed(v)
 
     def __set__(self, obj, value) -> None:
-        speed = FlashSpeed.value_for_speed(value)
+        speed = FlashSpeed.speed_for_value(value)
         super().__set__(obj, speed)
-        try:
-            obj.update()
-        except AttributeError:
-            logger.error(f"Failed to update {obj!r} after setting {self.name}")
 
 
 class BlyncLight(BitVector):
+    """BlyncLight
+
+    The Embrava BlyncLight family of USB connected products responds
+    to a 9-byte command word. The command word enables activation or
+    deactivation of various features; turning the light on and off,
+    changing it's color, causing the light to flash, dimming or
+    brightening, playing musical tunes stored in some BlyncLight
+    model's firmware, muting or changing the volume of the playing
+    music.
+
+    Not all devices have musical capability and music related
+    functionality has not yet been tested. 3 Apr 2019
+
+    The recommended way to obtain a BlyncLight object is to use the
+    class method get_light().
+
+    >>> light = BlyncLight.get_light()
+
+    Features of the light are controlled by assigning values to
+    attributes of the BlyncLight object:
+
+    >>> light.red = 0xff
+    >>> light.on = 1
+    >>> light.on = 0
+
+    Usage Notes
+    ===========
+
+    The BlyncLight object is an in-memory representation of the
+    state of the hardware device. I have not been able to discern how
+    to read the device's current state, so every time a new object is
+    instantiated it writes a known state to the device by default:
+    all fields zeros except off.
+
+    Additionally, any updates to the bit fields in the ByncLight class
+    will be immediately written to the hardware device by default.
+
+    Callers can defer hardware updates by setting the 'immediate'
+    attribute to False. Any changes to command fields will not be
+    written to the device. Setting 'immediate' to True will write the
+    current state of the command word to the device. The BlyncLight
+    object also provides a context manager method that can be used to
+    defer updates:
+
+    >>> with light.updates_paused():
+    ...     light.red = 0
+    ...     light.blue = 255
+    ...     light.green = 0
+    ...     light.on = True
+
+    is equivalent to:
+
+    >>> light.immediate = False
+    >>> light.red = 0
+    >>> light.blue = 255
+    >>> light.green = 0
+    >>> light.on = True
+    >>> light.immediate = True
+
+    is equivalent (almost) to:
+
+    >>> light.color = (0, 255, 0)
+    >>> light.on = True
+
+    ===CAVEAT===
+
+    Before turning the light on, make sure to specify a color
+    otherwise the device will not emit any light. It can be
+    very frustrating to turn the light on and not have any
+    noticible effect.
+
+    Command Word Documentation
+    ==========================
+
+
+    The Embrava BlyncLight command word bit fields are:
+
+    report : 8     Must be zero
+    red    : 8     Red component value between 0-255
+    blue   : 8     Blue component value between 0-255
+    green  : 8     Green component value between 0-255
+    off    : 1     0==on     1==off
+    dim    : 1     0==bright 1==dim
+    flash  : 1     0==steady 1==flash
+    speed  : 3     0==off 1==low 2==medium 4==fast
+    pad    : 2
+    mute   : 1     0==unmute 1==mute
+    music  : 4     select a built-in musical tune
+    play   : 1     0==stop 1==play
+    repeat : 1     0==no repeat 1==repeat
+    pad    : 2
+    volume : 4     1-10, increase volume by 10% per increment
+    pad    : 2
+    eoc    : 16    End Of Command field, must be 0xffff
+    """
+
     @classmethod
     def available_lights(cls) -> List[Dict[str, Union[int, str]]]:
         """
@@ -64,7 +156,7 @@ class BlyncLight(BitVector):
         try:
             light = cls.available_lights()[light_id]
         except IndexError:
-            raise BlyncLightNotFound(light_id)
+            raise BlyncLightNotFound(f"Light not found: {light_id}")
 
         return cls(light["vendor_id"], light["product_id"], immediate)
 
@@ -96,7 +188,7 @@ class BlyncLight(BitVector):
     play = BlyncCommand(28, 1)
     music = BlyncCommand(24, 4)
     mute = BlyncCommand(23, 1)
-    volume = BlyncCommand(16, 4)
+    volume = BlyncCommand(18, 4)
 
     def __repr__(self):
         return f"{self.__class__.__name__}({self.identifier})"
